==> jc-1.4.0.tar.gz: java/security/cert/CertPathValidator.h <==
// public class java.security.cert.CertPathValidator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 372fbbfc6ebbb881 java_security_cert_CertPathValidator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CertPathValidator_H_
#define _JC_java_security_cert_CertPathValidator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Provider$object;
struct _jc_java_security_cert_CertPath$object;
struct _jc_java_security_cert_CertPathParameters$object;
struct _jc_java_security_cert_CertPathValidator$object;
struct _jc_java_security_cert_CertPathValidatorResult$object;
struct _jc_java_security_cert_CertPathValidatorSpi$object;

// Typedefs
typedef struct _jc_java_security_cert_CertPathValidator$sub_refs	_jc_java_security_cert_CertPathValidator$sub_refs;
typedef struct _jc_java_security_cert_CertPathValidator$sub_nonrefs	_jc_java_security_cert_CertPathValidator$sub_nonrefs;
typedef struct _jc_java_security_cert_CertPathValidator$refs	_jc_java_security_cert_CertPathValidator$refs;
typedef struct _jc_java_security_cert_CertPathValidator$nonrefs	_jc_java_security_cert_CertPathValidator$nonrefs;
typedef struct _jc_java_security_cert_CertPathValidator$object	_jc_java_security_cert_CertPathValidator$object;

typedef struct _jc_java_security_cert_CertPathValidator$fields_struct	_jc_java_security_cert_CertPathValidator$fields_struct;
typedef const struct _jc_java_security_cert_CertPathValidator$vmethods	_jc_java_security_cert_CertPathValidator$vmethods;
typedef const struct _jc_java_security_cert_CertPathValidator$vtable	_jc_java_security_cert_CertPathValidator$vtable;
typedef const struct _jc_java_security_cert_CertPathValidator$vtype	_jc_java_security_cert_CertPathValidator$vtype;

// Class fields structure
struct _jc_java_security_cert_CertPathValidator$fields_struct {
	struct _jc_java_lang_String$object	*CERT__5fPATH__5fVALIDATOR;
};
extern _jc_java_security_cert_CertPathValidator$fields_struct _jc_java_security_cert_CertPathValidator$class_fields;

// Constructors
extern void _jc_java_security_cert_CertPathValidator$method$_init$07a7bafb3ae394af(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *, struct _jc_java_security_cert_CertPathValidatorSpi$object *, struct _jc_java_security_Provider$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CertPathValidator$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *);
extern struct _jc_java_security_Provider$object *_jc_java_security_cert_CertPathValidator$method$getProvider$e8f9c9fb14140d5a(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *);
extern struct _jc_object *_jc_java_security_cert_CertPathValidator$method$validate$d2f7c8575d4ae5f2(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertPathValidator$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_java_security_cert_CertPathValidator$method_info$getProvider$e8f9c9fb14140d5a;
extern _jc_method _jc_java_security_cert_CertPathValidator$method_info$validate$d2f7c8575d4ae5f2;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CertPathValidator$method$getDefaultType$e0168af0ff28954a(_jc_env *);
extern struct _jc_java_security_cert_CertPathValidator$object *_jc_java_security_cert_CertPathValidator$method$getInstance$01873effe531a9b4(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_security_cert_CertPathValidator$object *_jc_java_security_cert_CertPathValidator$method$getInstance$9867fe95dbb00c1b(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_security_cert_CertPathValidator$object *_jc_java_security_cert_CertPathValidator$method$getInstance$996066ac3ac4a9ef(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_security_Provider$object *);

// Virtual methods structure
struct _jc_java_security_cert_CertPathValidator$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *);
	struct _jc_java_security_Provider$object	*(*getProvider$e8f9c9fb14140d5a)(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *);
	struct _jc_object	*(*validate$d2f7c8575d4ae5f2)(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_object *);
};

// Vtable
struct _jc_java_security_cert_CertPathValidator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertPathValidator$vmethods	java_security_cert_CertPathValidator;
};

// Vtype
struct _jc_java_security_cert_CertPathValidator$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertPathValidator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertPathValidator$sub_refs {
	struct _jc_java_security_cert_CertPathValidatorSpi$object	*validatorSpi;
	struct _jc_java_security_Provider$object	*provider;
	struct _jc_java_lang_String$object	*algorithm;
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertPathValidator$refs {
    _jc_java_security_cert_CertPathValidator$sub_refs	java_security_cert_CertPathValidator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertPathValidator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertPathValidator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertPathValidator$sub_nonrefs	java_security_cert_CertPathValidator;
};

// Object instance structure
struct _jc_java_security_cert_CertPathValidator$object {
	_jc_java_security_cert_CertPathValidator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertPathValidator$vtype	*vtype;
	_jc_java_security_cert_CertPathValidator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertPathValidator$vtype _jc_java_security_cert_CertPathValidator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertPathValidator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertPathValidator$class_object;

#endif	/* _JC_java_security_cert_CertPathValidator_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/CertPathValidator.h <==
// public class java.security.cert.CertPathValidator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 372fbbfc6ebbb881 java_security_cert_CertPathValidator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CertPathValidator_H_
#define _JC_java_security_cert_CertPathValidator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Provider$object;
struct _jc_java_security_cert_CertPath$object;
struct _jc_java_security_cert_CertPathParameters$object;
struct _jc_java_security_cert_CertPathValidator$object;
struct _jc_java_security_cert_CertPathValidatorResult$object;
struct _jc_java_security_cert_CertPathValidatorSpi$object;

// Typedefs
typedef struct _jc_java_security_cert_CertPathValidator$sub_refs	_jc_java_security_cert_CertPathValidator$sub_refs;
typedef struct _jc_java_security_cert_CertPathValidator$sub_nonrefs	_jc_java_security_cert_CertPathValidator$sub_nonrefs;
typedef struct _jc_java_security_cert_CertPathValidator$refs	_jc_java_security_cert_CertPathValidator$refs;
typedef struct _jc_java_security_cert_CertPathValidator$nonrefs	_jc_java_security_cert_CertPathValidator$nonrefs;
typedef struct _jc_java_security_cert_CertPathValidator$object	_jc_java_security_cert_CertPathValidator$object;

typedef struct _jc_java_security_cert_CertPathValidator$fields_struct	_jc_java_security_cert_CertPathValidator$fields_struct;
typedef const struct _jc_java_security_cert_CertPathValidator$vmethods	_jc_java_security_cert_CertPathValidator$vmethods;
typedef const struct _jc_java_security_cert_CertPathValidator$vtable	_jc_java_security_cert_CertPathValidator$vtable;
typedef const struct _jc_java_security_cert_CertPathValidator$vtype	_jc_java_security_cert_CertPathValidator$vtype;

// Class fields structure
struct _jc_java_security_cert_CertPathValidator$fields_struct {
	struct _jc_java_lang_String$object	*CERT__5fPATH__5fVALIDATOR;
};
extern _jc_java_security_cert_CertPathValidator$fields_struct _jc_java_security_cert_CertPathValidator$class_fields;

// Constructors
extern void _jc_java_security_cert_CertPathValidator$method$_init$07a7bafb3ae394af(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *, struct _jc_java_security_cert_CertPathValidatorSpi$object *, struct _jc_java_security_Provider$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CertPathValidator$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_Provider$object *_jc_java_security_cert_CertPathValidator$method$getProvider$e8f9c9fb14140d5a(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_cert_CertPathValidator$method$validate$d2f7c8575d4ae5f2(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertPathValidator$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_java_security_cert_CertPathValidator$method_info$getProvider$e8f9c9fb14140d5a;
extern _jc_method _jc_java_security_cert_CertPathValidator$method_info$validate$d2f7c8575d4ae5f2;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_security_cert_CertPathValidator$method$getDefaultType$e0168af0ff28954a(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_security_cert_CertPathValidator$object *_jc_java_security_cert_CertPathValidator$method$getInstance$01873effe531a9b4(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_cert_CertPathValidator$object *_jc_java_security_cert_CertPathValidator$method$getInstance$9867fe95dbb00c1b(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_cert_CertPathValidator$object *_jc_java_security_cert_CertPathValidator$method$getInstance$996066ac3ac4a9ef(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_security_Provider$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_security_cert_CertPathValidator$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_Provider$object	*(*getProvider$e8f9c9fb14140d5a)(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*validate$d2f7c8575d4ae5f2)(_jc_env *, struct _jc_java_security_cert_CertPathValidator$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_CertPathValidator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertPathValidator$vmethods	java_security_cert_CertPathValidator;
};

// Vtype
struct _jc_java_security_cert_CertPathValidator$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertPathValidator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertPathValidator$sub_refs {
	struct _jc_java_security_cert_CertPathValidatorSpi$object	*validatorSpi;
	struct _jc_java_security_Provider$object	*provider;
	struct _jc_java_lang_String$object	*algorithm;
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertPathValidator$refs {
    _jc_java_security_cert_CertPathValidator$sub_refs	java_security_cert_CertPathValidator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertPathValidator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertPathValidator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertPathValidator$sub_nonrefs	java_security_cert_CertPathValidator;
};

// Object instance structure
struct _jc_java_security_cert_CertPathValidator$object {
	_jc_java_security_cert_CertPathValidator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertPathValidator$vtype	*vtype;
	_jc_java_security_cert_CertPathValidator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertPathValidator$vtype _jc_java_security_cert_CertPathValidator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertPathValidator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertPathValidator$class_object;

#endif	/* _JC_java_security_cert_CertPathValidator_H_ */
